@@ -5,7 +5,7 @@
 ;; Author: Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2023
-;; Version: 1.6
+;; Version: 1.7
 ;; Package-Requires: ((emacs "27.1") (compat "29.1.4.4"))
 ;; Homepage: https://github.com/minad/jinx
 ;; Keywords: convenience, text
@@ -81,6 +81,12 @@
   "Dictionary language codes, as a string separated by whitespace."
   :type 'string)
 
+(defcustom jinx-save-languages 'ask
+  "Save the variable `jinx-languages' as file-local variable?"
+  :type '(choice (const :tag "Never"  nil)
+                 (const :tag "Always" t)
+                 (const :tag "Ask"    ask)))
+
 ;;;###autoload
 (put 'jinx-languages 'safe-local-variable #'stringp)
 
@@ -136,11 +142,11 @@ Set to t to enable camelCase everywhere."
     (emacs-lisp-mode
      font-lock-constant-face font-lock-warning-face)
     (message-mode
-     message-header-cc message-header-name message-header-newsgroups
-     message-header-other message-header-to message-header-xheader
-     message-cited-text-1 message-cited-text-2 message-cited-text-3
-     message-cited-text-4 gnus-cite-1 gnus-cite-2 gnus-cite-3
-     gnus-cite-4 gnus-cite-5 gnus-cite-6 gnus-cite-7 gnus-cite-8
+     message-separator message-header-cc message-header-name
+     message-header-newsgroups message-header-other message-header-to
+     message-header-xheader message-cited-text-1 message-cited-text-2
+     message-cited-text-3 message-cited-text-4 gnus-cite-1 gnus-cite-2
+     gnus-cite-3 gnus-cite-4 gnus-cite-5 gnus-cite-6 gnus-cite-7 gnus-cite-8
      gnus-cite-9 gnus-cite-10 gnus-cite-11))
   "Alist of faces per major mode.
 These faces mark regions which should be excluded in spell
@@ -935,8 +941,10 @@ buffers.  See also the variable `jinx-languages'."
    (t
     (setq-local jinx-languages langs)
     (when (or (assq 'jinx-languages file-local-variables-alist)
-              (and buffer-file-name
-                   (y-or-n-p "Save `jinx-languages' as file-local variable? ")))
+              (if (eq jinx-save-languages 'ask)
+                  (and buffer-file-name
+                       (y-or-n-p "Save `jinx-languages' as file-local variable? "))
+                jinx-save-languages))
       (add-file-local-variable 'jinx-languages jinx-languages)
       (setf (alist-get 'jinx-languages file-local-variables-alist) jinx-languages))))
   (jinx--load-dicts)
